# package_name

Description. 
The package pacote_moozer is used to:
	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pacote_moozer

```bash
pip install pacote_moozer
```

## Usage

```python
from pacote_moozer.module1_name import file1_name
file1_name.my_function()
```

## Author
Moozer

## License
[MIT](https://choosealicense.com/licenses/mit/)